@@ -23,9 +23,6 @@
 
 static void         gail_calendar_class_init          (GailCalendarClass *klass);
 
-
-static gpointer parent_class = NULL;
-
 GType
 gail_calendar_get_type (void)
 {
@@ -56,7 +53,6 @@ gail_calendar_get_type (void)
 static void
 gail_calendar_class_init (GailCalendarClass *klass)
 {
-  parent_class = g_type_class_ref (GAIL_TYPE_CONTAINER);
 }
 
 AtkObject* 
@@ -69,9 +65,9 @@ gail_calendar_new (GtkWidget *widget)
 
   object = g_object_new (GAIL_TYPE_CALENDAR, NULL);
 
-  gail_widget_init (GAIL_WIDGET (object), widget);
-
   accessible = ATK_OBJECT (object);
+  atk_object_initialize (accessible, widget);
+
   accessible->role = ATK_ROLE_CALENDAR;
 
   return accessible;
