@@ -80,7 +80,7 @@ gail_image_class_init (GailImageClass *klass)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 
-  parent_class = g_type_class_ref (GAIL_TYPE_WIDGET);
+  parent_class = g_type_class_peek_parent (klass);
 
   gobject_class->finalize = gail_image_finalize;
 }
@@ -101,9 +101,9 @@ gail_image_new (GtkWidget *widget)
 
   object = g_object_new (GAIL_TYPE_IMAGE, NULL);
 
-  gail_widget_init (GAIL_WIDGET (object), widget);
-
   accessible = ATK_OBJECT (object);
+  atk_object_initialize (accessible, widget);
+
   accessible->role = ATK_ROLE_ICON;
 
   return accessible;
