@@ -97,7 +97,7 @@ gail_image_cell_class_init (GailImageCellClass *klass)
   GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
   GailRendererCellClass *renderer_cell_class = GAIL_RENDERER_CELL_CLASS(klass);
 
-  parent_class = g_type_class_ref (GAIL_TYPE_RENDERER_CELL);
+  parent_class = g_type_class_peek_parent (klass);
 
   gobject_class->finalize = gail_image_cell_finalize;
 
