@@ -105,7 +105,6 @@ gail_item_get_name (AtkObject *obj)
       GtkWidget *widget;
       GList *children;
       GList *tmp_list;
-      GValue  value = { 0, };
 
       widget = GTK_ACCESSIBLE (obj)->widget;
       if (widget == NULL)
@@ -125,10 +124,8 @@ gail_item_get_name (AtkObject *obj)
    
           if (GTK_IS_LABEL (widget))
             {
-              g_value_init (&value, G_TYPE_STRING);
-              g_object_get_property (G_OBJECT(widget), "label", &value);
               g_list_free (children);
-              return g_value_get_string (&value);
+	      return gtk_label_get_text (GTK_LABEL(widget));
             }
           tmp_list = tmp_list->next;
         }
