@@ -35,9 +35,6 @@ static gboolean     gail_menu_shell_is_child_selected   (AtkSelection   *selecti
 static gboolean     gail_menu_shell_remove_selection    (AtkSelection   *selection,
                                                          gint           i);
 
-
-static gpointer parent_class = NULL;
-
 GType
 gail_menu_shell_get_type (void)
 {
@@ -78,11 +75,6 @@ gail_menu_shell_get_type (void)
 static void
 gail_menu_shell_class_init (GailMenuShellClass *klass)
 {
-  GailWidgetClass *widget_class;
-
-  widget_class = (GailWidgetClass*)klass;
-
-  parent_class = g_type_class_ref (GAIL_TYPE_CONTAINER);
 }
 
 AtkObject*
@@ -95,9 +87,9 @@ gail_menu_shell_new (GtkWidget *widget)
 
   object = g_object_new (GAIL_TYPE_MENU_SHELL, NULL);
 
-  gail_widget_init (GAIL_WIDGET (object), widget);
-
   accessible = ATK_OBJECT (object);
+  atk_object_initialize (accessible, widget);
+
   if (GTK_IS_MENU_BAR (widget))
     accessible->role = ATK_ROLE_MENU_BAR;
   else
