@@ -26,8 +26,8 @@
 static void         gail_notebook_class_init          (GailNotebookClass *klass);
 static void         gail_notebook_object_init         (GailNotebook      *notebook);
 static void         gail_notebook_finalize            (GObject           *object);
-static void         gail_notebook_real_init           (GailWidget        *widget,
-                                                       GtkWidget         *gtk_widget);
+static void         gail_notebook_real_initialize     (AtkObject         *obj,
+                                                       gpointer          data);
 
 static void         gail_notebook_real_notify_gtk     (GObject           *obj,
                                                        GParamSpec        *pspec);
@@ -92,14 +92,14 @@ gail_notebook_class_init (GailNotebookClass *klass)
 
   widget_class = (GailWidgetClass*)klass;
 
-  parent_class = g_type_class_ref (GAIL_TYPE_CONTAINER);
+  parent_class = g_type_class_peek_parent (klass);
   
   gobject_class->finalize = gail_notebook_finalize;
 
-  widget_class->init = gail_notebook_real_init;
   widget_class->notify_gtk = gail_notebook_real_notify_gtk;
 
   class->ref_child = gail_notebook_ref_child;
+  class->initialize = gail_notebook_real_initialize;
   /*
    * We do not provide an implementation of get_n_children
    * as the implementation in GailContainer returns the correct
@@ -124,9 +124,9 @@ gail_notebook_new (GtkWidget *widget)
 
   object = g_object_new (GAIL_TYPE_NOTEBOOK, NULL);
 
-  gail_widget_init (GAIL_WIDGET (object), widget);
-
   accessible = ATK_OBJECT (object);
+  atk_object_initialize (accessible, widget);
+
   accessible->role = ATK_ROLE_PAGE_TAB_LIST;
 
   return accessible;
@@ -178,17 +178,16 @@ gail_notebook_ref_child (AtkObject      *obj,
 }
 
 static void
-gail_notebook_real_init (GailWidget         *widget,
-                         GtkWidget          *gtk_widget)
+gail_notebook_real_initialize (AtkObject *obj,
+                               gpointer  data)
 {
-  GailNotebook *notebook = GAIL_NOTEBOOK (widget);
-  GtkNotebook *gtk_notebook = GTK_NOTEBOOK (gtk_widget);
+  GailNotebook *notebook = GAIL_NOTEBOOK (obj);
+  GtkNotebook *gtk_notebook = GTK_NOTEBOOK (data);
   GtkWidget *page;
   gint i;
 
-  GAIL_WIDGET_CLASS (parent_class)->init (widget, gtk_widget);
+  ATK_OBJECT_CLASS (parent_class)->initialize (obj, data);
 
-  i = atk_object_get_n_accessible_children (ATK_OBJECT (widget));
   i = 0;
   page = gtk_notebook_get_nth_page (gtk_notebook, i);
   while (page)
@@ -214,8 +213,6 @@ gail_notebook_real_notify_gtk (GObject           *obj,
       gint page_num, old_page_num;
       GailNotebook *gail_notebook = GAIL_NOTEBOOK (atk_obj);
      
-      g_signal_emit_by_name (atk_obj, "selection_changed");
-
       /*
        * Notify SELECTED state change for old and new page
        */
@@ -227,6 +224,9 @@ gail_notebook_real_notify_gtk (GObject           *obj,
         {
           AtkObject *obj;
 
+          g_signal_emit_by_name (atk_obj, "selection_changed");
+          g_signal_emit_by_name (atk_obj, "visible_data_changed");
+
           obj = find_child_in_list (gail_notebook->page_cache, old_page_num);
           if (obj)
             atk_object_notify_state_change (obj,
