@@ -59,12 +59,9 @@ gail_radio_button_get_type (void)
 static void
 gail_radio_button_class_init (GailRadioButtonClass *klass)
 {
-  GailWidgetClass *widget_class;
   AtkObjectClass *class = ATK_OBJECT_CLASS (klass);
 
-  widget_class = (GailWidgetClass*)klass;
-
-  parent_class = g_type_class_ref (GAIL_TYPE_TOGGLE_BUTTON);
+  parent_class = g_type_class_peek_parent (klass);
 
   class->ref_relation_set = gail_radio_button_ref_relation_set;
 }
@@ -79,9 +76,9 @@ gail_radio_button_new (GtkWidget *widget)
 
   object = g_object_new (GAIL_TYPE_RADIO_BUTTON, NULL);
 
-  gail_widget_init (GAIL_WIDGET (object), widget);
-
   accessible = ATK_OBJECT (object);
+  atk_object_initialize (accessible, widget);
+
   accessible->role = ATK_ROLE_RADIO_BUTTON;
   return accessible;
 }
