@@ -26,7 +26,7 @@ static void gail_text_cell_factory_class_init (GailTextCellFactoryClass        *
 static AtkObject* gail_text_cell_factory_create_accessible (
                                 GObject                              *obj);
 
-static AtkObjectFactoryClass    *parent_class = NULL;
+static GType gail_text_cell_factory_get_accessible_type (void);
 
 GType
 gail_text_cell_factory_get_type ()
@@ -60,12 +60,12 @@ gail_text_cell_factory_class_init (GailTextCellFactoryClass *klass)
 {
   AtkObjectFactoryClass *class = ATK_OBJECT_FACTORY_CLASS (klass);
 
-  parent_class = g_type_class_ref (ATK_TYPE_OBJECT_FACTORY);
-
   class->create_accessible = gail_text_cell_factory_create_accessible;
+  class->get_accessible_type = gail_text_cell_factory_get_accessible_type;
 }
 
-AtkObjectFactory* gail_text_cell_factory_new ()
+AtkObjectFactory*
+gail_text_cell_factory_new ()
 {
   GObject *factory;
 
@@ -81,3 +81,9 @@ gail_text_cell_factory_create_accessible (GObject     *obj)
 
   return gail_text_cell_new ();
 }
+
+static GType
+gail_text_cell_factory_get_accessible_type (void)
+{
+  return GAIL_TYPE_TEXT_CELL;
+}
