@@ -117,22 +117,26 @@ gail_toplevel_object_init (GailToplevel *toplevel)
   GList *l;
   guint signal_id;
 
-  toplevel->window_list = gtk_window_list_toplevels ();
+  l = toplevel->window_list = gtk_window_list_toplevels ();
 
-  if (toplevel->window_list)
+  while (l)
     {
-      /* Must loop through them all and set up signal connections */
-      for (l = toplevel->window_list; l; l = l->next)
+      window = GTK_WINDOW (l->data);
+      if (!window || GTK_WIDGET (window)->parent)
         {
-          window = GTK_WINDOW (l->data);
-          if (window != NULL)
-            {
-              g_signal_connect (G_OBJECT (window), 
-                                "destroy",
-                                G_CALLBACK (gail_toplevel_window_destroyed),
-                                toplevel);
-            }
+          GList *temp_l  = l->next;
+
+          toplevel->window_list = g_list_delete_link (toplevel->window_list, l);
+          l = temp_l;
         }
+      else
+        {
+          g_signal_connect (G_OBJECT (window), 
+                            "destroy",
+                            G_CALLBACK (gail_toplevel_window_destroyed),
+                            toplevel);
+        }
+      l = l->next;
     }
 
   gtk_type_class (GTK_TYPE_WINDOW);
@@ -207,6 +211,7 @@ gail_toplevel_show_event_watcher (GSignalInvocationHint *ihint,
   GailToplevel *toplevel = GAIL_TOPLEVEL (data);
   AtkObject *atk_obj = ATK_OBJECT (toplevel);
   GObject *object;
+  GtkWidget *widget;
   gint n_children;
 
   object = g_value_get_object (param_values + 0);
@@ -214,9 +219,12 @@ gail_toplevel_show_event_watcher (GSignalInvocationHint *ihint,
   if (!GTK_IS_WINDOW (object))
     return TRUE;
 
+  widget = GTK_WIDGET (object);
+  if (widget->parent)
+    return TRUE;
+
   /* Add the window to the list & emit the signal */
-  toplevel->window_list = g_list_append (toplevel->window_list, 
-                                         GTK_WIDGET (object));
+  toplevel->window_list = g_list_append (toplevel->window_list, widget);
 
   n_children = g_list_length (toplevel->window_list);
 
