@@ -28,7 +28,7 @@ static void gail_window_factory_class_init (
 static AtkObject* gail_window_factory_create_accessible (
                                 GObject                         *obj);
 
-static AtkObjectFactoryClass    *parent_class = NULL;
+static GType gail_window_factory_get_accessible_type (void);
 
 GType
 gail_window_factory_get_type ()
@@ -62,12 +62,12 @@ gail_window_factory_class_init (GailWindowFactoryClass *klass)
 {
   AtkObjectFactoryClass *class = ATK_OBJECT_FACTORY_CLASS (klass);
 
-  parent_class = g_type_class_ref (ATK_TYPE_OBJECT_FACTORY);
-
   class->create_accessible = gail_window_factory_create_accessible;
+  class->get_accessible_type = gail_window_factory_get_accessible_type;
 }
 
-AtkObjectFactory* gail_window_factory_new ()
+AtkObjectFactory* 
+gail_window_factory_new ()
 {
   GObject *factory;
 
@@ -86,3 +86,9 @@ gail_window_factory_create_accessible (GObject     *obj)
   widget = GTK_WIDGET (obj);
   return gail_window_new (widget);
 }
+
+static GType
+gail_window_factory_get_accessible_type (void)
+{
+  return GAIL_TYPE_WINDOW;
+}
